@@ -1,7 +1,6 @@
 use super::EnumKind;
-use rustc_hash::FxHashMap;
 use swc_atoms::js_word;
-use swc_common::{util::move_map::MoveMap, Spanned, DUMMY_SP};
+use swc_common::{collections::AHashMap, util::move_map::MoveMap, Spanned, DUMMY_SP};
 use swc_ecma_ast::*;
 use swc_ecma_utils::{ident::IdentLike, member_expr, quote_ident, undefined, ExprFactory, Id};
 use swc_ecma_visit::{noop_fold_type, Fold, FoldWith};
@@ -121,7 +120,7 @@ impl ParamMetadata {
 
 /// https://github.com/leonardfactory/babel-plugin-transform-typescript-metadata/blob/master/src/metadata/metadataVisitor.ts
 pub(super) struct Metadata<'a> {
-    pub(super) enums: &'a FxHashMap<Id, EnumKind>,
+    pub(super) enums: &'a AHashMap<Id, EnumKind>,
 
     pub(super) class_name: Option<&'a Ident>,
 }
